OC.L10N.register(
    "documents",
    {
    "Documents" : "ドキュメント",
    "Can't create document" : "文書を生成することができません",
    "You don't have permission to rename this document" : "ドキュメント名を変更する権限がありません",
    "Directory saved successfully." : "ディレクトリの保存に成功しました。",
    "An error occurred while changing directory." : "ディレクトリの変更中にエラーが発生しました。",
    "Saved" : "保存されました",
    "Format filter server is down or misconfigured" : "フォーマットフィルターサーバーが稼働していないか設定ミス",
    "Conversion failed. Check log for details." : "変換に失敗しました。詳細についてはログを確認してください。",
    "Saving..." : "保存中...",
    "Failed to load documents." : "ドキュメントのロードに失敗しました。",
    "No documents were found. Upload or create a document to get started!" : "ドキュメントはありません。アップロードもしくは新規に作成してください！",
    "No connection to server. Trying to reconnect." : "サーバーに接続されていません。再接続してください。",
    "Leaving this page in Editor mode might cause unsaved data. It is recommended to use 'Close' button instead." : "このページを編集モードのままにしておくと、保存されないデータが出てきます。その代わりに「閉じる」ボタンを使うことをお勧めします。",
    "Failed to load this document. Please check if it can be opened with an external odt editor. This might also mean it has been unshared or deleted recently." : "ドキュメントの読み込みに失敗しました。外部の odtエディターで開けるかどうか確認してください。これは、ドキュメントが最近、非共有になっているか削除されているのかもしれません。",
    "Save" : "保存",
    "Loading documents..." : "ドキュメントを読込中...",
    "'.' is an invalid file name." : "'.' は無効なファイル名です。",
    "File name cannot be empty." : "ファイル名を空にすることはできません。",
    "Invalid name, '\\', '/', '<', '>', ':', '\"', '|', '?' and '*' are not allowed." : "無効な名前、'\\', '/', '<', '>', ':', '\"', '|', '?', '*' は使用できません。",
    "Align Left" : "左揃え",
    "Alignment" : "配置",
    "Align Right" : "右揃え",
    "Annotate" : "注釈",
    "Background" : "背景",
    "Bold" : "ボールド",
    "Bottom" : "下",
    "Cancel" : "キャンセル",
    "Center" : "中央",
    "Clone" : "複製",
    "Clone this Style" : "このスタイルを複製",
    "Close" : "閉じる",
    "Color" : "色",
    "Create" : "作成",
    "Decrease Indent" : "インデントを減らす",
    "Default Style" : "デフォルトスタイル",
    "Delete" : "削除",
    "Family" : "家族",
    "Font" : "フォント",
    "Font Effects" : "フォント効果",
    "Format" : "書式",
    "Increase Indent" : "インデントを増やす",
    "Insert Image" : "画像を挿入",
    "Invite Members" : "メンバーを招待",
    "Italic" : "イタリック",
    "Justified" : "両端揃え",
    "Justify" : "両端揃え",
    "Left" : "左",
    "Loading" : "読込中",
    "Members" : "メンバー",
    "New Name:" : "新しい名前:",
    "OK" : "OK",
    "Open" : "開く",
    "Options" : "オプション",
    "Paragraph..." : "段落...",
    "Paragraph Styles" : "段落スタイル",
    "Redo" : "やり直し",
    "Right" : "右",
    "Size" : "サイズ",
    "Spacing" : "間隔",
    "Strikethrough" : "取消線",
    "Style" : "スタイル",
    "Text" : "TTY TDD",
    "Top" : "上",
    "Underline" : "下線",
    "Undo" : "元に戻す",
    "Unknown Author" : "不明な作者",
    "Shared" : "共有中",
    "Error" : "エラー",
    "Error while sharing" : "共有でエラー発生",
    "Error while unsharing" : "共有解除でエラー発生",
    "Error while changing permissions" : "権限変更でエラー発生",
    "Shared with you and the group {group} by {owner}" : "あなたと {owner} のグループ {group} で共有中",
    "Shared with you by {owner}" : "{owner} と共有中",
    "Share with users or groups …" : "ユーザーもしくはグループと共有 ...",
    "Share with users, groups or remote users …" : "ユーザー、グループもしくはリモートユーザーと共有 ...",
    "Share" : "共有",
    "Share with people on other ownClouds using the syntax username@example.com/owncloud" : "次の形式で指定して他のownCloudのユーザーと、共有",
    "Share link" : "URLで共有",
    "The public link will expire no later than {days} days after it is created" : "URLによる共有は、作成してから {days} 日以内に有効期限切れになります",
    "Link" : "リンク",
    "Password protect" : "パスワード保護を有効化",
    "Password" : "パスワード",
    "Choose a password for the public link" : "URLによる共有のパスワードを入力",
    "Allow editing" : "編集許可",
    "Email link to person" : "メールリンク",
    "Send" : "送信",
    "Set expiration date" : "有効期限を設定",
    "Expiration" : "期限切れ",
    "Expiration date" : "有効期限",
    "An error occured. Please try again" : "エラーが発生しました。もう一度トライしてください。",
    "Adding user..." : "ユーザーを追加しています...",
    "group" : "グループ",
    "remote" : "リモート",
    "Resharing is not allowed" : "再共有は許可されていません",
    "Shared in {item} with {user}" : "{item} 内で {user} と共有中",
    "Unshare" : "共有解除",
    "notify by email" : "メールで通知",
    "can share" : "共有可",
    "can edit" : "編集を許可",
    "access control" : "アクセス権限",
    "create" : "作成",
    "change" : "更新",
    "delete" : "削除",
    "Password protected" : "パスワード保護",
    "Error unsetting expiration date" : "有効期限の未設定エラー",
    "Error setting expiration date" : "有効期限の設定でエラー発生",
    "Sending ..." : "送信中...",
    "Email sent" : "メールを送信しました",
    "Warning" : "警告",
    "Edit" : "編集",
    "guest" : "ゲスト",
    "MS Word support (requires openOffice/libreOffice)" : "MS Wordサポート (OpenOffice/LibreOfficeが必要)",
    "Local" : "ローカル",
    "openOffice/libreOffice is installed on this server. Path to binary is provided via preview_libreoffice_path in config.php" : "openOffice/libreOffice はこのサーバーにインストールされています。バイナリへのパスは、config.php の preview_libreoffice_path で指定することができます。",
    "External" : "外部",
    "openOffice/libreOffice is installed on external server running a format filter server" : "openOffice/libreOffice は、フォーマットフィルターサーバーが動作している外部サーバーにインストールされています。",
    "Disabled" : "無効",
    "No MS Word support" : "MS Wordはサポートしていません。",
    "scheme://domain.tld[:port]" : "scheme://domain.tld[:port]",
    "Server URL" : "サーバーURL",
    "Apply and test" : "適用してテスト",
    "New document" : "新しいドキュメント",
    "Upload (max. %s)" : "アップロード ( 最大 %s )",
    "Upload" : "アップロード",
    "Save new documents to" : "新規ドキュメントの保存先:",
    "Wrong password. Please retry." : "間違ったパスワード。もう一度入力してください。",
    "Guest %s" : "ゲスト %s",
    "This link has been expired or is never existed. Please contact the person who shared it with you for details." : "このリンクは期限が切れているか、すでに存在しません。詳細は、それを共有した方に連絡していください。",
    "Advanced feature-set" : "高度な機能セット",
    "(Unstable)" : "(不安定)"
},
"nplurals=1; plural=0;");
